ranking: Create ranking from vector

View source: R/ranking.R

rankingR Documentation

Create ranking from vector

Description

Given a numeric vector, the default behavior creates a ranking in ascending value. This is, the lower the value of the vector the better the candidate is considered. If names are given in the vector they will be used as names of the candidates, to overwrite them, use the argument 'cnames'.

Usage

ranking(v, cnames = NULL, desc = FALSE)

Arguments

v

vector to be translated to a ranking.

cnames

names of the candidates. The values in this vector cannot must identified uniquely each candidate, thus, repeated values are not allowed.

desc

Default is FALSE. Therefore the rankings are creating in ascending value

See Also

Other ranking: parse_ranking()


noeliarico/consensus documentation built on March 18, 2023, 12:37 p.m.