| ranking | R Documentation |
Given a numeric vector, the default behavior creates a ranking in ascending value. This is, the lower the value of the vector the better the candidate is considered. If names are given in the vector they will be used as names of the candidates, to overwrite them, use the argument 'cnames'.
ranking(v, cnames = NULL, desc = FALSE)
v |
vector to be translated to a ranking. |
cnames |
names of the candidates. The values in this vector cannot must identified uniquely each candidate, thus, repeated values are not allowed. |
desc |
Default is FALSE. Therefore the rankings are creating in ascending value |
Other ranking:
parse_ranking()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.